#!/usr/bin/env python3

"""
Nemesida WAF API
Copyright (c) 2017-2024 Pentestit LLC - All Rights Reserved
Author: Romanov R.
"""

from psycopg2.extras import RealDictCursor

from core import base_api_uri
from core import init_db_connection
from core import log

##
# URLs
##

set_mt_data_uri = base_api_uri + '/set_mt_data_uri'
get_mt_data_uri = base_api_uri + '/get_mt_data_uri'
get_mt_hash_uri = base_api_uri + '/get_mt_hash_uri'


##
# Functions
##

def lower_dict_keys(data_dict):
    return {key.lower() if isinstance(key, str) else key: value for key, value in data_dict.items()}


def mt_get_export(waf_id):

    # init
    res = ()

    try:

        query = """ SELECT * FROM mt_export WHERE waf_id = %s """
        connect = init_db_connection()
        cursor = connect.cursor(cursor_factory=RealDictCursor)
        cursor.execute(query, (waf_id,))
        res = cursor.fetchall()
        connect.close()

    except Exception as e:
        log.error('An error occurred while processing data in mt_export for WAF ID {}: {}'.format(waf_id, e))

    return res


def mt_get_export_md5(waf_id):

    # init
    res = '0'

    try:

        query = """ SELECT md5(CAST(array_agg(mt_export.*) AS TEXT)) FROM mt_export WHERE waf_id = %s """
        connect = init_db_connection()
        cursor = connect.cursor(cursor_factory=RealDictCursor)
        cursor.execute(query, (waf_id,))
        res = cursor.fetchall()
        connect.close()

        if res and res[0]['md5']:
            res = str(res[0]['md5'])
        else:
            res = '0'

    except Exception as e:
        log.error('An error occurred while processing hash in mt_export for WAF ID {}: {}'.format(waf_id, e))

    return res
