#!/usr/bin/python3

"""
Nemesida WAF API
Copyright (c) 2017-2024 Pentestit LLC - All Rights Reserved
Author: Romanov R.
"""

import logging

from logging.handlers import RotatingFileHandler
from time import time, sleep

from core import cc_upd_db
from core import get_rldesc
from core import init_db_connection
from core import ro_mode

from ec import event_eol


##
# Misc.
##

logf = '/var/log/uwsgi/nw-api/rldscupd-logging.log'

##
# Log settings
##

log = logging.getLogger('main')
log.setLevel(logging.INFO)
fh = logging.handlers.RotatingFileHandler(logf, maxBytes=50 * 1024 * 1024, backupCount=5)
formatter = logging.Formatter('[%(asctime)s] %(levelname)s - %(message)s', '%m-%d %H:%M:%S')
fh.setFormatter(formatter)
log.addHandler(fh)
log.info('START')


def db_update():
    try:

        # RW DB type only
        if ro_mode:
            return

        # init database connection
        connect = init_db_connection()
        cursor = connect.cursor()

        ##
        # Processing rule description in attack
        ##

        sql = """
            SELECT DISTINCT
                rule_id
            FROM
                attack
            WHERE
                description IS NULL OR description = '' OR description = '-'
        """
        cursor.execute(sql,)
        rows = cursor.fetchall()

        if len(rows):
            for i in rows:

                # init
                rule_id = str(i[0])

                if rule_id == '0':
                    continue

                # receive rule description if rule id not 0
                rldesc = get_rldesc(rule_id)
                log.info('Updated description for RuleID {}: {}'.format(rule_id, rldesc))

                # if rule description is not empty
                if rldesc:

                    # update description
                    query = """ UPDATE attack SET description = %s WHERE rule_id = %s """
                    cursor.execute(query, (rldesc, rule_id,))

        ##
        # Processing CC in attack
        ##

        for table in ['attack', 'mt_main']:
            cc_upd_db(table)

        ##
        # Delete old events
        ##

        try:

            # Set a timestamp, less than which all events will be deleted
            eol_ts = int(time()) - event_eol

            # Delete an events
            sql = """ DELETE FROM events WHERE timestamp < %s """
            cursor.execute(sql, (eol_ts,))

        except Exception as e:
            log.error('An error occurred while deleting old events: {}'.format(e))

        # close database connection
        connect.close()

    except Exception as e:
        log.error('An error occurred while processing data: {}'.format(e))


if __name__ == '__main__':
    while True:
        db_update()
        sleep(5)
